@@ -1,12 +1,10 @@
 module ByteString.TreeBuilder.Poker where
 
 import ByteString.TreeBuilder.Prelude
-import Foreign hiding (void)
-import qualified Data.ByteString as A
-import qualified Data.ByteString.Internal as B
-import qualified Foreign as D
 import qualified ByteString.TreeBuilder.Tree as E
-
+import qualified Data.ByteString.Internal as B
+import Foreign hiding (void)
+import qualified Foreign as D
 
 -- |
 -- Write the given bytes into the pointer and
@@ -15,7 +13,7 @@ pokeBytes :: ByteString -> Ptr Word8 -> IO (Ptr Word8)
 pokeBytes (B.PS foreignPointer offset length) pointer =
   do
     withForeignPtr foreignPointer $ \pointer' ->
-      B.memcpy pointer (plusPtr pointer' offset) length
+      copyBytes pointer (plusPtr pointer' offset) length
     pure (plusPtr pointer length)
 
 -- |
@@ -25,7 +23,7 @@ pokeBytesMinus :: ByteString -> Ptr Word8 -> IO (Ptr Word8)
 pokeBytesMinus (B.PS foreignPointer offset length) pointer =
   do
     withForeignPtr foreignPointer $ \pointer' ->
-      B.memcpy targetPointer (plusPtr pointer' offset) length
+      copyBytes targetPointer (plusPtr pointer' offset) length
     pure targetPointer
   where
     targetPointer =
