@@ -1,18 +1,11 @@
 module ByteString.TreeBuilder.Tree where
 
-import ByteString.TreeBuilder.Prelude hiding (foldl, foldr, foldlM, length)
-import qualified Data.ByteString as B
-import qualified Data.ByteString.Internal as C
-import qualified Data.ByteString.Lazy.Internal as E
-import qualified ByteString.TreeBuilder.Prelude as F
-import qualified Data.ByteString.Internal as G
-import qualified Foreign as H
+import ByteString.TreeBuilder.Prelude hiding (foldl, foldlM, foldr, length)
 
-
-data Tree =
-  Empty |
-  Leaf !ByteString |
-  Branch !Tree !Tree
+data Tree
+  = Empty
+  | Leaf !ByteString
+  | Branch !Tree !Tree
 
 {-# INLINE foldl #-}
 foldl :: (a -> ByteString -> a) -> a -> Tree -> a
@@ -37,7 +30,7 @@ foldr step init =
       foldr step (foldr step init tree2) tree1
 
 {-# INLINE foldlM #-}
-foldlM :: Monad m => (a -> ByteString -> m a) -> a -> Tree -> m a
+foldlM :: (Monad m) => (a -> ByteString -> m a) -> a -> Tree -> m a
 foldlM step init =
   \case
     Empty ->
